==> acceleratedrendering-1.0.5.1-1.21.1-alpha-fabric.1-sources.jar: com/github/argon4w/acceleratedrendering/compat/trinkets/TrinketsCompatFeature.java <==
package com.github.argon4w.acceleratedrendering.compat.trinkets;

import com.github.argon4w.acceleratedrendering.configs.FeatureConfig;
import com.github.argon4w.acceleratedrendering.configs.FeatureStatus;
import com.github.argon4w.acceleratedrendering.features.filter.FilterType;
import it.unimi.dsi.fastutil.objects.ReferenceOpenHashSet;
import java.util.ArrayDeque;
import java.util.Deque;
import java.util.Set;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_2960;
import net.minecraft.class_7923;

public class TrinketsCompatFeature {

	public	static final Deque	<FeatureStatus> LAYER_ACCELERATION_CONTROLLER_STACK		= new ArrayDeque<>			();
	public	static final Deque	<FeatureStatus> CURIOS_ITEM_FILTER_CONTROLLER_STACK		= new ArrayDeque<>			();
	private	static final Set	<class_1792>			CURIOS_ITEM_FILTER_VALUES				= new ReferenceOpenHashSet<>();

	static {
		FeatureConfig.CONFIG.trinketsItemFilterValues.get().forEach(string -> CURIOS_ITEM_FILTER_VALUES.add(class_7923.field_41178.method_10223(class_2960.method_12829(string))));
	}

	public static boolean isEnabled() {
		return FeatureConfig.CONFIG.trinketsCompatFeatureStatus.get() == FeatureStatus.ENABLED;
	}

	public static boolean testTrinketsItem(class_1799 itemStack) {
		return getTrinketsItemFilterType().test(CURIOS_ITEM_FILTER_VALUES, itemStack.method_7909());
	}

	public static boolean shouldAccelerateTrinkets() {
		return getLayerAccelerationSetting() == FeatureStatus.ENABLED;
	}

	public static boolean shouldFilterTrinketsItems() {
		return getTrinketsItemFilterSetting() == FeatureStatus.ENABLED;
	}

	public static FilterType getTrinketsItemFilterType() {
		return FeatureConfig.CONFIG.trinketsItemFilterType.get();
	}

	public static void disableLayerAcceleration() {
		LAYER_ACCELERATION_CONTROLLER_STACK.push(FeatureStatus.DISABLED);
	}

	public static void disableTrinketsItemFilter() {
		CURIOS_ITEM_FILTER_CONTROLLER_STACK.push(FeatureStatus.DISABLED);
	}

	public static void forceEnableLayerAcceleration() {
		LAYER_ACCELERATION_CONTROLLER_STACK.push(FeatureStatus.ENABLED);
	}

	public static void forceEnableTrinketsItemFilter() {
		CURIOS_ITEM_FILTER_CONTROLLER_STACK.push(FeatureStatus.ENABLED);
	}

	public static void forceSetLayerAcceleration(FeatureStatus status) {
		LAYER_ACCELERATION_CONTROLLER_STACK.push(status);
	}

	public static void forceSetTrinketsItemFilter(FeatureStatus status) {
		CURIOS_ITEM_FILTER_CONTROLLER_STACK.push(status);
	}

	public static void resetLayerAcceleration() {
		LAYER_ACCELERATION_CONTROLLER_STACK.pop();
	}

	public static void resetTrinketsItemFilter() {
		CURIOS_ITEM_FILTER_CONTROLLER_STACK.pop();
	}

	public static FeatureStatus getLayerAccelerationSetting() {
		return LAYER_ACCELERATION_CONTROLLER_STACK.isEmpty() ? getDefaultLayerAccelerationSettings() : LAYER_ACCELERATION_CONTROLLER_STACK.peek();
	}

	public static FeatureStatus getTrinketsItemFilterSetting() {
		return CURIOS_ITEM_FILTER_CONTROLLER_STACK.isEmpty() ? getDefaultTrinketsItemFilterSetting() : CURIOS_ITEM_FILTER_CONTROLLER_STACK.peek();
	}

	public static FeatureStatus getDefaultLayerAccelerationSettings() {
		return FeatureConfig.CONFIG.trinketsCompatLayerAcceleration.get();
	}

	public static FeatureStatus getDefaultTrinketsItemFilterSetting() {
		return FeatureConfig.CONFIG.trinketsItemFilter.get();
	}
}

==> acceleratedrendering-1.0.6-1.21.1-alpha-fabric.1-sources.jar: com/github/argon4w/acceleratedrendering/compat/trinkets/TrinketsCompatFeature.java <==
package com.github.argon4w.acceleratedrendering.compat.trinkets;

import com.github.argon4w.acceleratedrendering.configs.FeatureConfig;
import com.github.argon4w.acceleratedrendering.configs.FeatureStatus;
import com.github.argon4w.acceleratedrendering.core.utils.RegistryFilter;
import com.github.argon4w.acceleratedrendering.features.filter.FilterType;
import java.util.ArrayDeque;
import java.util.Deque;
import java.util.Set;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_7923;

public class TrinketsCompatFeature {

	public	static final Deque	<FeatureStatus> LAYER_ACCELERATION_CONTROLLER_STACK	= new ArrayDeque<>();
	public	static final Deque	<FeatureStatus> CURIOS_ITEM_FILTER_CONTROLLER_STACK	= new ArrayDeque<>();
	private	static final Set	<class_1792>			CURIOS_ITEM_FILTER_VALUES;

	static {
		CURIOS_ITEM_FILTER_VALUES = RegistryFilter.filterValues(class_7923.field_41178, FeatureConfig.CONFIG.trinketsItemFilterValues.get());
	}

	public static boolean isEnabled() {
		return FeatureConfig.CONFIG.trinketsCompatFeatureStatus.get() == FeatureStatus.ENABLED;
	}

	public static boolean testTrinketsItem(class_1799 itemStack) {
		return getTrinketsItemFilterType().test(CURIOS_ITEM_FILTER_VALUES, itemStack.method_7909());
	}

	public static boolean shouldAccelerateTrinkets() {
		return getLayerAccelerationSetting() == FeatureStatus.ENABLED;
	}

	public static boolean shouldFilterTrinketsItems() {
		return getTrinketsItemFilterSetting() == FeatureStatus.ENABLED;
	}

	public static FilterType getTrinketsItemFilterType() {
		return FeatureConfig.CONFIG.trinketsItemFilterType.get();
	}

	public static void disableLayerAcceleration() {
		LAYER_ACCELERATION_CONTROLLER_STACK.push(FeatureStatus.DISABLED);
	}

	public static void disableTrinketsItemFilter() {
		CURIOS_ITEM_FILTER_CONTROLLER_STACK.push(FeatureStatus.DISABLED);
	}

	public static void forceEnableLayerAcceleration() {
		LAYER_ACCELERATION_CONTROLLER_STACK.push(FeatureStatus.ENABLED);
	}

	public static void forceEnableTrinketsItemFilter() {
		CURIOS_ITEM_FILTER_CONTROLLER_STACK.push(FeatureStatus.ENABLED);
	}

	public static void forceSetLayerAcceleration(FeatureStatus status) {
		LAYER_ACCELERATION_CONTROLLER_STACK.push(status);
	}

	public static void forceSetTrinketsItemFilter(FeatureStatus status) {
		CURIOS_ITEM_FILTER_CONTROLLER_STACK.push(status);
	}

	public static void resetLayerAcceleration() {
		LAYER_ACCELERATION_CONTROLLER_STACK.pop();
	}

	public static void resetTrinketsItemFilter() {
		CURIOS_ITEM_FILTER_CONTROLLER_STACK.pop();
	}

	public static FeatureStatus getLayerAccelerationSetting() {
		return LAYER_ACCELERATION_CONTROLLER_STACK.isEmpty() ? getDefaultLayerAccelerationSettings() : LAYER_ACCELERATION_CONTROLLER_STACK.peek();
	}

	public static FeatureStatus getTrinketsItemFilterSetting() {
		return CURIOS_ITEM_FILTER_CONTROLLER_STACK.isEmpty() ? getDefaultTrinketsItemFilterSetting() : CURIOS_ITEM_FILTER_CONTROLLER_STACK.peek();
	}

	public static FeatureStatus getDefaultLayerAccelerationSettings() {
		return FeatureConfig.CONFIG.trinketsCompatLayerAcceleration.get();
	}

	public static FeatureStatus getDefaultTrinketsItemFilterSetting() {
		return FeatureConfig.CONFIG.trinketsItemFilter.get();
	}
}
